@@ -13,7 +13,9 @@ from .DropDownMenu import DropDownMenu
 from .FadeTransition import FadeTransition
 from .FontIcon import FontIcon
 from .GrowTransition import GrowTransition
+from .Pagination import Pagination
 from .Paper import Paper
+from .Picker import Picker
 from .Popover import Popover
 from .RadioButtonGroup import RadioButtonGroup
 from .SlideTransition import SlideTransition
@@ -22,6 +24,7 @@ from .Stepper import Stepper
 from .Subheader import Subheader
 from .Tabs import Tabs
 from .Toggle import Toggle
+from .Tooltip import Tooltip
 from .ZoomTransition import ZoomTransition
 
 __all__ = [
@@ -40,7 +43,9 @@ __all__ = [
     "FadeTransition",
     "FontIcon",
     "GrowTransition",
+    "Pagination",
     "Paper",
+    "Picker",
     "Popover",
     "RadioButtonGroup",
     "SlideTransition",
@@ -49,5 +54,6 @@ __all__ = [
     "Subheader",
     "Tabs",
     "Toggle",
+    "Tooltip",
     "ZoomTransition"
 ]
\ No newline at end of file
